@@ -52,6 +52,7 @@ public class JavaBridge {
  static String oldEventName = null;
  static int oldDetail1 = -1;
  static boolean debugFlag = false;
+ static Application the_app;
 
  javax.accessibility.Accessible appAccessible;
 
@@ -87,7 +88,15 @@ public class JavaBridge {
 				}
 				if (ac != null) {
 					org.GNOME.Accessibility.Accessible accessible = getAccessibleObjectFactory().getAccessible(ac);
-					any.insert_Object (accessible, AccessUtil.getORB().get_primitive_tc (TCKind.tk_objref));
+
+					EventDetails ed = new EventDetails();
+					ed.host_application = the_app;
+					ed.source_role = accessible.getRole();
+					ed.source_name = accessible.name();
+					ed.any_data = AccessUtil.getORB().create_any ();
+					AccessibleHelper.insert(ed.any_data, accessible);
+					EventDetailsHelper.insert (any, ed);
+
 					detail1 = ac.getAccessibleIndexInParent ();
 				}
 				dispatchEvent(source, 
@@ -121,7 +130,7 @@ public class JavaBridge {
 				if ( textEvent ) {
 				    int selection_start = 0, selection_end = 0;
 				    int selection_change_start = 0, selection_change_end = 0;
-				    org.omg.CORBA.Any selection_any = AccessUtil.getORB().create_any ();
+				    org.omg.CORBA.Any any = AccessUtil.getORB().create_any ();
 				    AccessibleContext ac = null;
 				    if (source instanceof AccessibleContext) 
 					ac = (AccessibleContext) source;
@@ -162,14 +171,21 @@ public class JavaBridge {
 					selection_change_end = selection_end;
 				    }
 				    if (new_selection) {
-					selection_any.insert_string (oldFocusText.substring (
+					 org.GNOME.Accessibility.Accessible accessible = getAccessibleObjectFactory().getAccessible(ac);
+					EventDetails ed = new EventDetails();
+					ed.host_application = the_app;
+					ed.source_role =  accessible.getRole();
+					ed.source_name = accessible.name();
+					ed.any_data = AccessUtil.getORB().create_any();
+					ed.any_data.insert_string (oldFocusText.substring (
 									 Math.min (selection_change_start, 
 									      selection_change_end),
 									 Math.max (selection_change_start,
 									      selection_change_end)));
+					EventDetailsHelper.insert (any, ed);
 					dispatchEvent(source,
 						      "object:text-selection-changed", 
-						      selection_start, selection_end, selection_any);
+						      selection_start, selection_end, any);
 				    }
 				}
 				else {
@@ -408,9 +424,20 @@ public class JavaBridge {
 //                                    eventSource.toString() );
 				return;
 			}
+
 			org.GNOME.Accessibility.Accessible accessible = 
 				getAccessibleObjectFactory().
 				getAccessible(ac);
+
+			if (!any.type().equivalent(EventDetailsHelper.type())) {
+				EventDetails ed = new EventDetails();
+				ed.host_application = the_app;
+				ed.source_role = accessible.getRole();
+				ed.source_name = accessible.name();
+				ed.any_data = AccessUtil.getORB().create_any();
+				EventDetailsHelper.insert (any, ed);
+			}
+
 			org.GNOME.Accessibility.Event event = 
 				new org.GNOME.Accessibility.Event (eventName, 
 								   accessible,
@@ -453,7 +480,6 @@ public class JavaBridge {
 
 	public static void dispatchFocusEvent(java.lang.Object eventSource) {
 		AccessibleContext ctx;
-		org.omg.CORBA.Any any = AccessUtil.getORB().create_any ();
 
 		// System.err.println ("dispatchFocusEvent: " + eventSource);
 		if (eventSource == null) {
@@ -546,6 +572,14 @@ public class JavaBridge {
             }
   			org.GNOME.Accessibility.Accessible accessible = 
 			      JavaBridge.getAccessibleObjectFactory().getAccessible(ctx);
+
+			org.omg.CORBA.Any any = AccessUtil.getORB().create_any ();
+			EventDetails ed = new EventDetails();
+			ed.host_application = the_app;
+			ed.source_role = accessible.getRole();
+			ed.source_name = accessible.name();
+			ed.any_data =  AccessUtil.getORB().create_any ();
+			EventDetailsHelper.insert (any, ed);
 			org.GNOME.Accessibility.Event event = new org.GNOME.Accessibility.Event
 				("focus:", accessible, 0, 0, any);
 			// System.out.println("focus: " + ctx);
@@ -1064,6 +1098,7 @@ public class JavaBridge {
             
 			Application aref = getAccessibleObjectFactory().
                                getApplication(appAccessible.getAccessibleContext());
+			the_app = aref;
             
 			if (debugFlag)
 				System.err.println(aref);
